@@ -1,4 +1,5 @@
 use MooseX::Declare;
+use warnings;
 
 class TSQL::AST::SQLFragment {
 
@@ -14,7 +15,7 @@ Version 0.01_001
 
 =cut
 
-our $VERSION = '0.01';
+#our \$VERSION  = '0.01';
 
 
 has 'tokenString' => (
@@ -94,7 +95,7 @@ This is the method which parses the split up SQL code.
 
 This is the method that holds the raw input text corresponding to the parsed SQL fragment.
 Derived classes representing compound objects do not populate this field, but delegate it to
-their consituent parts.
+their constituent parts.
 
 
 =head1 LIMITATIONS
