@@ -1,9 +1,9 @@
 use MooseX::Declare;
+use warnings;
 
 class TSQL::AST::SQLScript extends TSQL::AST::SQLFragment {
 
 use TSQL::AST::SQLBatch;
-use 5.010;
 use Data::Dumper;
 
 =head1 NAME
@@ -12,11 +12,11 @@ TSQL::AST::SQLScript - Represents a TSQL Script.
 
 =head1 VERSION
 
-Version 0.01 
+Version 0.02 
 
 =cut
 
-our $VERSION = '0.01';
+#our \$VERSION  = '0.02';
 
 has 'batches' => (
       is  => 'rw',
@@ -37,7 +37,6 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input ) {
 
 1;
 
-__DATA__
 
 __DATA__
 
@@ -105,7 +104,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST
+    perldoc TSQL::AST::SQLScript
 
 
 You can also look for information at:
