@@ -1,4 +1,5 @@
 use MooseX::Declare;
+use warnings;
 
 class TSQL::AST::SQLStatement extends TSQL::AST::SQLFragment {
 
@@ -12,7 +13,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+#our \$VERSION  = '0.01';
 
 }
 
@@ -65,7 +66,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST
+    perldoc TSQL::AST::SQLStatement
 
 
 You can also look for information at:
