@@ -1,4 +1,5 @@
 use MooseX::Declare;
+use warnings;
 
 class TSQL::AST::SQLWhileStatement extends TSQL::AST::SQLStatement {
 
@@ -8,8 +9,8 @@ use TSQL::AST::SQLStatement;
 use TSQL::AST::SQLStatementBlock;
 use TSQL::AST::SQLTryCatchBlock;
 #use TSQL::AST::SQLStatementBlock;
+use TSQL::AST::SQLIfStatement;
 
-use TSQL::Common::Regexp;
 
 
 =head1 NAME
@@ -18,11 +19,11 @@ TSQL::AST::SQLWhileStatement - Represents a TSQL While Statement.
 
 =head1 VERSION
 
-Version 0.01 
+Version 0.02 
 
 =cut
 
-our $VERSION = '0.02';
+#our \$VERSION  = '0.02';
 
 use feature "switch";
 
@@ -44,9 +45,6 @@ has 'body' => (
 override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
 
 #    while ( $$index <= $#{$input} ) {
-        my $qr_iftoken               //= TSQL::Common::Regexp->qr_iftoken();
-        my $qr_elsetoken             //= TSQL::Common::Regexp->qr_elsetoken();
-        my $qr_whiletoken            //= TSQL::Common::Regexp->qr_whiletoken();
     
         my $ln = $$input[$$index];
         my $t = TSQL::AST::Factory->makeToken($ln);
@@ -71,31 +69,25 @@ override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
                 $$index++;
                 my $block = TSQL::AST::SQLStatementBlock->new( statements => [] ) ;
                 $block->parse($index,$input);
-                push @{$self->statements()}, $block;
+                $self->body($block);                
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::BeginTry') ) {
                 $$index++;
                 my $block = TSQL::AST::SQLTryCatchBlock->new( tryBlock => [],catchBlock => [] ) ;
                 $block->parse($index,$input);
-                push @{$self->statements()}, $block;
+                $self->body($block);                
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::If') ) {
-                my $condition = $ln;
-                $condition =~ s{$qr_iftoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b if \b)}{}xmis ;
-                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
-                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
-                my $block = TSQL::AST::SQLIfStatement->new( condition => $co ) ;            
+                $$index++;
+                my $block = TSQL::AST::Factory->makeIfStatement($ln);
                 $block->parse($index,$input);
-                push @{$self->statements()}, $block;
+                $self->body($block);                
             }
             when ( defined $_ && $_->isa('TSQL::AST::Token::While') ) {
                 $$index++;
-                my $condition = $ln;
-                $condition =~ s{$qr_whiletoken}{}xmis; # s{\A \s* (?:\b if \b)}{}xmis ;$condition =~ s{\A \s* (?:\b while \b)}{}xmis ;
-                my $fr = TSQL::AST::SQLFragment->new( tokenString => $condition ) ; 
-                my $co = TSQL::AST::SQLConditionalExpression->new( expression => $fr ) ; 
-                my $block = TSQL::AST::SQLWhileStatement->new( condition => $co ) ;            
-                push @{$self->statements()}, $block;
+                my $block = TSQL::AST::Factory->makeWhileStatement($ln);
+                $block->parse($index,$input);
+                $self->body($block);                
             }                
 
             default { 
@@ -168,7 +160,7 @@ This is the method which parses the split up SQL code.
 
 =item * C<< $while->condition() >>
 
-TSQL::AST::SQLConditionalExpression representing the condtion clause of the While statement.
+TSQL::AST::SQLConditionalExpression representing the condition clause of the While statement.
     
 =back    
 
@@ -195,7 +187,7 @@ Please report any problematic cases.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc TSQL::AST
+    perldoc TSQL::AST::SQLWhileStatement
 
 
 You can also look for information at:
